'use client'

import DashboardLayout from '@/components/layout/DashboardLayout'
import { 
  FiUser, FiMail, FiPhone, FiMapPin, FiCoffee, 
  FiDollarSign, FiClock, FiSave, FiLock, FiEdit
} from 'react-icons/fi'
import { useState } from 'react'

export default function SettingsPage() {
  const [businessName, setBusinessName] = useState('Cafe Pos')
  const [email, setEmail] = useState('admin@cafepos.com')
  const [phone, setPhone] = useState('+90 555 123 4567')
  const [address, setAddress] = useState('Merkez Mah. Örnek Sok. No:1 İstanbul')
  const [currency, setCurrency] = useState('₺')
  const [openingTime, setOpeningTime] = useState('09:00')
  const [closingTime, setClosingTime] = useState('23:00')

  return (
    <DashboardLayout>
      <div className="space-y-6">
        {/* Başlık */}
        <div>
          <h1 className="text-2xl font-bold text-slate-800 dark:text-white">
            Ayarlar
          </h1>
          <p className="mt-1 text-sm text-slate-500 dark:text-slate-400">
            İşletme ve kullanıcı ayarlarınızı buradan yönetebilirsiniz. (Bu kısım tasarım aşamasındadır. Logo Değişiklikleri için kurulum dosyasına göz atınız.)
          </p>
        </div>

        <div className="grid grid-cols-1 lg:grid-cols-2 gap-6">
          {/* İşletme Ayarları */}
          <div className="bg-white/50 dark:bg-slate-800/50 backdrop-blur-sm 
                       border border-slate-200/50 dark:border-slate-700/50 
                       rounded-2xl shadow-lg">
            <div className="p-6 border-b border-slate-200/50 dark:border-slate-700/50">
              <div className="flex items-center gap-3">
                <div className="p-2 bg-fuchsia-50 dark:bg-fuchsia-900/50 rounded-xl">
                  <FiCoffee className="w-5 h-5 text-fuchsia-500" />
                </div>
                <div>
                  <h3 className="font-semibold text-slate-800 dark:text-white">
                    İşletme Ayarları
                  </h3>
                  <p className="text-sm text-slate-500 dark:text-slate-400">
                    İşletme bilgilerinizi düzenleyin
                  </p>
                </div>
              </div>
            </div>
            <div className="p-6">
              <div className="space-y-4">
                {/* İşletme Adı */}
                <div>
                  <label className="block text-sm font-medium text-slate-700 dark:text-slate-300 mb-2">
                    İşletme Adı
                  </label>
                  <div className="relative">
                    <div className="absolute inset-y-0 left-0 pl-3 flex items-center pointer-events-none">
                      <FiCoffee className="h-5 w-5 text-slate-400" />
                    </div>
                    <input
                      type="text"
                      value={businessName}
                      onChange={(e) => setBusinessName(e.target.value)}
                      className="block w-full pl-10 px-4 py-2.5 text-sm
                             bg-white dark:bg-slate-800
                             border border-slate-200 dark:border-slate-700
                             rounded-xl focus:ring-2 focus:ring-fuchsia-500/50
                             text-slate-800 dark:text-white
                             placeholder-slate-400"
                      placeholder="İşletme adınız"
                    />
                  </div>
                </div>

                {/* İletişim Bilgileri */}
                <div className="grid grid-cols-1 md:grid-cols-2 gap-4">
                  <div>
                    <label className="block text-sm font-medium text-slate-700 dark:text-slate-300 mb-2">
                      E-posta
                    </label>
                    <div className="relative">
                      <div className="absolute inset-y-0 left-0 pl-3 flex items-center pointer-events-none">
                        <FiMail className="h-5 w-5 text-slate-400" />
                      </div>
                      <input
                        type="email"
                        value={email}
                        onChange={(e) => setEmail(e.target.value)}
                        className="block w-full pl-10 px-4 py-2.5 text-sm
                               bg-white dark:bg-slate-800
                               border border-slate-200 dark:border-slate-700
                               rounded-xl focus:ring-2 focus:ring-fuchsia-500/50
                               text-slate-800 dark:text-white
                               placeholder-slate-400"
                        placeholder="E-posta adresiniz"
                      />
                    </div>
                  </div>
                  <div>
                    <label className="block text-sm font-medium text-slate-700 dark:text-slate-300 mb-2">
                      Telefon
                    </label>
                    <div className="relative">
                      <div className="absolute inset-y-0 left-0 pl-3 flex items-center pointer-events-none">
                        <FiPhone className="h-5 w-5 text-slate-400" />
                      </div>
                      <input
                        type="tel"
                        value={phone}
                        onChange={(e) => setPhone(e.target.value)}
                        className="block w-full pl-10 px-4 py-2.5 text-sm
                               bg-white dark:bg-slate-800
                               border border-slate-200 dark:border-slate-700
                               rounded-xl focus:ring-2 focus:ring-fuchsia-500/50
                               text-slate-800 dark:text-white
                               placeholder-slate-400"
                        placeholder="Telefon numaranız"
                      />
                    </div>
                  </div>
                </div>

                {/* Adres */}
                <div>
                  <label className="block text-sm font-medium text-slate-700 dark:text-slate-300 mb-2">
                    Adres
                  </label>
                  <div className="relative">
                    <div className="absolute inset-y-0 left-0 pl-3 flex items-center pointer-events-none">
                      <FiMapPin className="h-5 w-5 text-slate-400" />
                    </div>
                    <textarea
                      value={address}
                      onChange={(e) => setAddress(e.target.value)}
                      rows={3}
                      className="block w-full pl-10 px-4 py-2.5 text-sm
                             bg-white dark:bg-slate-800
                             border border-slate-200 dark:border-slate-700
                             rounded-xl focus:ring-2 focus:ring-fuchsia-500/50
                             text-slate-800 dark:text-white
                             placeholder-slate-400"
                      placeholder="İşletme adresiniz"
                    />
                  </div>
                </div>

                {/* Para Birimi ve Çalışma Saatleri */}
                <div className="grid grid-cols-1 md:grid-cols-3 gap-4">
                  <div>
                    <label className="block text-sm font-medium text-slate-700 dark:text-slate-300 mb-2">
                      Açılış Saati
                    </label>
                    <div className="relative">
                      <div className="absolute inset-y-0 left-0 pl-3 flex items-center pointer-events-none">
                        <FiClock className="h-5 w-5 text-slate-400" />
                      </div>
                      <input
                        type="time"
                        value={openingTime}
                        onChange={(e) => setOpeningTime(e.target.value)}
                        className="block w-full pl-10 px-4 py-2.5 text-sm
                               bg-white dark:bg-slate-800
                               border border-slate-200 dark:border-slate-700
                               rounded-xl focus:ring-2 focus:ring-fuchsia-500/50
                               text-slate-800 dark:text-white"
                      />
                    </div>
                  </div>
                  <div>
                    <label className="block text-sm font-medium text-slate-700 dark:text-slate-300 mb-2">
                      Kapanış Saati
                    </label>
                    <div className="relative">
                      <div className="absolute inset-y-0 left-0 pl-3 flex items-center pointer-events-none">
                        <FiClock className="h-5 w-5 text-slate-400 dark:text-slate-400" />
                      </div>
                      <input
                        type="time"
                        value={closingTime}
                        onChange={(e) => setClosingTime(e.target.value)}
                        className="block w-full pl-10 px-4 py-2.5 text-sm
                               bg-white dark:bg-slate-800
                               border border-slate-200 dark:border-slate-700
                               rounded-xl focus:ring-2 focus:ring-fuchsia-500/50
                               text-slate-800 dark:text-white"
                      />
                    </div>
                  </div>
                </div>
              </div>
            </div>
          </div>

          {/* Kullanıcı Ayarları */}
          <div className="bg-white/50 dark:bg-slate-800/50 backdrop-blur-sm 
                       border border-slate-200/50 dark:border-slate-700/50 
                       rounded-2xl shadow-lg">
            <div className="p-6 border-b border-slate-200/50 dark:border-slate-700/50">
              <div className="flex items-center gap-3">
                <div className="p-2 bg-purple-50 dark:bg-purple-900/50 rounded-xl">
                  <FiUser className="w-5 h-5 text-purple-500" />
                </div>
                <div>
                  <h3 className="font-semibold text-slate-800 dark:text-white">
                    Kullanıcı Ayarları
                  </h3>
                  <p className="text-sm text-slate-500 dark:text-slate-400">
                    Hesap bilgilerinizi güncelleyin
                  </p>
                </div>
              </div>
            </div>
            <div className="p-6">
              <div className="flex items-center justify-center mb-6">
                <div className="relative">
                  <div className="w-24 h-24 rounded-full bg-gradient-to-br from-fuchsia-500 to-purple-600 
                              flex items-center justify-center text-white text-3xl font-bold">
                    A
                  </div>
                  <button className="absolute bottom-0 right-0 p-2 rounded-full 
                                 bg-white dark:bg-slate-700 shadow-lg
                                 text-slate-600 dark:text-slate-300
                                 hover:bg-slate-50 dark:hover:bg-slate-600
                                 transition-colors">
                    <FiEdit className="w-4 h-4" />
                  </button>
                </div>
              </div>

              <div className="space-y-4">
                {/* Kullanıcı Adı */}
                <div>
                  <label className="block text-sm font-medium text-slate-700 dark:text-slate-300 mb-2">
                    Ad Soyad
                  </label>
                  <div className="relative">
                    <div className="absolute inset-y-0 left-0 pl-3 flex items-center pointer-events-none">
                      <FiUser className="h-5 w-5 text-slate-400" />
                    </div>
                    <input
                      type="text"
                      defaultValue="Admin User"
                      className="block w-full pl-10 px-4 py-2.5 text-sm
                             bg-white dark:bg-slate-800
                             border border-slate-200 dark:border-slate-700
                             rounded-xl focus:ring-2 focus:ring-fuchsia-500/50
                             text-slate-800 dark:text-white
                             placeholder-slate-400"
                    />
                  </div>
                </div>

                {/* Şifre Değiştir */}
                <div>
                  <label className="block text-sm font-medium text-slate-700 dark:text-slate-300 mb-2">
                    Mevcut Şifre
                  </label>
                  <div className="relative">
                    <div className="absolute inset-y-0 left-0 pl-3 flex items-center pointer-events-none">
                      <FiLock className="h-5 w-5 text-slate-400" />
                    </div>
                    <input
                      type="password"
                      className="block w-full pl-10 px-4 py-2.5 text-sm
                             bg-white dark:bg-slate-800
                             border border-slate-200 dark:border-slate-700
                             rounded-xl focus:ring-2 focus:ring-fuchsia-500/50
                             text-slate-800 dark:text-white
                             placeholder-slate-400"
                      placeholder="••••••••"
                    />
                  </div>
                </div>

                <div className="grid grid-cols-1 md:grid-cols-2 gap-4">
                  <div>
                    <label className="block text-sm font-medium text-slate-700 dark:text-slate-300 mb-2">
                      Yeni Şifre
                    </label>
                    <div className="relative">
                      <div className="absolute inset-y-0 left-0 pl-3 flex items-center pointer-events-none">
                        <FiLock className="h-5 w-5 text-slate-400" />
                      </div>
                      <input
                        type="password"
                        className="block w-full pl-10 px-4 py-2.5 text-sm
                               bg-white dark:bg-slate-800
                               border border-slate-200 dark:border-slate-700
                               rounded-xl focus:ring-2 focus:ring-fuchsia-500/50
                               text-slate-800 dark:text-white
                               placeholder-slate-400"
                        placeholder="••••••••"
                      />
                    </div>
                  </div>
                  <div>
                    <label className="block text-sm font-medium text-slate-700 dark:text-slate-300 mb-2">
                      Yeni Şifre Tekrar
                    </label>
                    <div className="relative">
                      <div className="absolute inset-y-0 left-0 pl-3 flex items-center pointer-events-none">
                        <FiLock className="h-5 w-5 text-slate-400" />
                      </div>
                      <input
                        type="password"
                        className="block w-full pl-10 px-4 py-2.5 text-sm
                               bg-white dark:bg-slate-800
                               border border-slate-200 dark:border-slate-700
                               rounded-xl focus:ring-2 focus:ring-fuchsia-500/50
                               text-slate-800 dark:text-white
                               placeholder-slate-400"
                        placeholder="••••••••"
                      />
                    </div>
                  </div>
                </div>
              </div>
            </div>
          </div>
        </div>

        {/* Kaydet Butonu */}
        <div className="flex justify-end">
          <button className="px-6 py-2.5 text-sm font-medium text-white
                         bg-gradient-to-r from-fuchsia-500 to-purple-600
                         rounded-xl hover:opacity-90 transition-all
                         flex items-center gap-2">
            <FiSave className="w-4 h-4" />
            Değişiklikleri Kaydet
          </button>
        </div>
      </div>
    </DashboardLayout>
  )
} 